@@ -91,6 +91,7 @@ $_gmsg['note_multicpufeature'] = 'This feature is available for Multiple-CPU lic
 $_gmsg['note_newver'] = 'New Release';
 $_gmsg['note_number'] = 'Number';
 $_gmsg['note_numvalidrange'] = 'Number valid range';
+$_gmsg['note_readonly_mode'] = 'Include file detected in configuration file. Entering Read-only mode.';
 $_gmsg['note_select_option'] = 'Please select';
 $_gmsg['note_serv_level'] = 'Server Level';
 $_gmsg['note_signout'] = 'Sign Out';
@@ -112,7 +113,6 @@ $_gmsg['err_sessiontimeout'] = 'Your session has timed out.';
 $_gmsg['err_valcannotempty'] = 'Value cannot be empty';
 
 
-$_gmsg['l_SSLStrongDhKey'] = 'SSL Strong DH Key';
 $_gmsg['l_accessallow'] = 'Allowed List';
 $_gmsg['l_accessallowed'] = 'Access Allowed';
 $_gmsg['l_accesscontrol'] = 'Access Control';
@@ -185,6 +185,7 @@ $_gmsg['l_certfile'] = 'Certificate File';
 $_gmsg['l_cgidsock'] = 'CGI Daemon Socket';
 $_gmsg['l_cgipriority'] = 'CGI Priority';
 $_gmsg['l_cgisettings'] = 'CGI Settings';
+$_gmsg['l_cgroups'] = 'cgroups';
 $_gmsg['l_checksymbollink'] = 'Check Symbolic Link';
 $_gmsg['l_chrootpath'] = 'chroot Path';
 $_gmsg['l_ciphers'] = 'Ciphers';
@@ -281,7 +282,7 @@ $_gmsg['l_forcegid'] = 'Force GID';
 $_gmsg['l_forcemimetype'] = 'Force MIME Type';
 $_gmsg['l_forcestrictownership'] = 'Force Strict Ownership';
 $_gmsg['l_generalsettings'] = 'General Settings';
-$_gmsg['l_geoipdb'] = 'IP to GeoLocation DB';
+$_gmsg['l_geoipdb'] = 'MaxMind GeoIP DB';
 $_gmsg['l_geoipdbfile'] = 'DB File Path';
 $_gmsg['l_gracefulrestarttimeout'] = 'Graceful Restart Timeout (secs)';
 $_gmsg['l_graceperiod'] = 'Grace Period (sec)';
@@ -313,7 +314,6 @@ $_gmsg['l_inittimeout'] = 'Initial Request Timeout (secs)';
 $_gmsg['l_inmembufsize'] = 'Memory I/O Buffer';
 $_gmsg['l_instances'] = 'Instances';
 $_gmsg['l_internal'] = 'Is Internal';
-$_gmsg['l_ioeventdispatcher'] = 'I/O Event Dispatcher';
 $_gmsg['l_ip'] = 'IP Address';
 $_gmsg['l_ip2locDB'] = 'IP2Location DB';
 $_gmsg['l_ip2locDBCache'] = 'DB Cache Type';
@@ -475,18 +475,7 @@ $_gmsg['l_sslSessionCacheTimeout'] = 'Session Cache Timeout (secs)';
 $_gmsg['l_sslSessionTicketKeyFile'] = 'SSL Session Ticket Key File';
 $_gmsg['l_sslSessionTicketLifetime'] = 'SSL Session Ticket Lifetime (secs)';
 $_gmsg['l_sslSessionTickets'] = 'Enable Session Tickets';
-$_gmsg['l_sslcryptodevice'] = 'SSL Hardware Accelerator';
-$_gmsg['l_sslopt4758cca'] = '(4758cca) IBM 4758 CCA hardware engine support';
-$_gmsg['l_ssloptaep'] = '(aep) Aep hardware engine support';
-$_gmsg['l_ssloptatalla'] = '(atalla) Atalla hardware engine support';
-$_gmsg['l_ssloptauto'] = '(auto) Automatically use available devices';
-$_gmsg['l_ssloptchil'] = '(chil) nCipher hardware engine support';
-$_gmsg['l_ssloptcswift'] = '(cswift) CryptoSwift hardware engine support';
-$_gmsg['l_ssloptdynamic'] = '(dynamic) Dynamic engine loading support';
-$_gmsg['l_ssloptnull'] = '(built-in) OpenSSL internal engine';
-$_gmsg['l_ssloptnuron'] = '(nuron) Nuron hardware engine support';
-$_gmsg['l_ssloptsureware'] = '(sureware) SureWare hardware engine support';
-$_gmsg['l_ssloptubsec'] = '(ubsec) UBSEC hardware engine support';
+$_gmsg['l_sslStrongDhKey'] = 'SSL Strong DH Key';
 $_gmsg['l_sslprotocol'] = 'SSL Protocol';
 $_gmsg['l_startupfile'] = 'Startup File';
 $_gmsg['l_statDir'] = 'Statistics Output Directory';
@@ -579,6 +568,8 @@ $_gmsg['o_noabort'] = 'No Abort';
 $_gmsg['o_nofornph'] = 'No for Non-Parsed-Header (NPH)';
 $_gmsg['o_none'] = 'None';
 $_gmsg['o_notset'] = 'Not Set';
+$_gmsg['o_on'] = 'On';
+$_gmsg['o_off'] = 'Off';
 $_gmsg['o_overridecpanelrestartscript'] = 'Override cPanel restart HTTPD script';
 $_gmsg['o_ownlogfile'] = 'Own Log File';
 $_gmsg['o_sameasserver'] = 'Same as Server';
@@ -597,11 +588,11 @@ $_gmsg['o_yesdaemonmode'] = 'Yes (Daemon Mode)';
 
 $_gmsg['parse_awstatsuri'] = 'starts with / and ends with /';
 $_gmsg['parse_compressibletypes'] = '(!)MIME types, like */*, text/*, text/html, text/*, !text/css';
-$_gmsg['parse_defaultmimetype'] = 'MEME_type like text/html';
+$_gmsg['parse_defaultmimetype'] = 'MIME_type like text/html';
 $_gmsg['parse_env'] = 'PROPERTY=VALUE';
 $_gmsg['parse_expiresByType'] = 'MIME_type=A|Mseconds, MIME type can be like */*, text/*, text/html';
 $_gmsg['parse_expiresdefault'] = '[A|M]###, A means client access time, M means file modified time, ### is number of seconds';
-$_gmsg['parse_forcemimetype'] = 'MEME_type like text/html, or put \\\"NONE\\\" to disable inherited Force Type.';
+$_gmsg['parse_forcemimetype'] = 'MIME_type like text/html, or put \\\"NONE\\\" to disable inherited Force Type.';
 $_gmsg['parse_geodbenv'] = 'Variable_Name mapped_DB_data';
 $_gmsg['parse_mimetype'] = 'like text/html';
 $_gmsg['parse_recaptchakey'] = 'key string assigned from your google reCAPTCHA account';
